==> bfilter-0.10.1.tar.gz: bfilter-0.10.1/main/HtmlNodeWithChildren.cpp <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "pch.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "HtmlNodeWithChildren.h"

HtmlNodeWithChildren::HtmlNodeWithChildren()
:	m_leftSentinel(this), m_rightSentinel(this)
{
	makeSentinelPair(&m_leftSentinel, &m_rightSentinel);
}

HtmlNodeWithChildren::HtmlNodeWithChildren(HtmlNodeWithChildren const& other)
:	m_leftSentinel(this), m_rightSentinel(this)
{
	makeSentinelPair(&m_leftSentinel, &m_rightSentinel);
	
	HtmlNode const* child = other.getFirstChild();
	for (; child; child = child->getNextSibling()) {
		appendChild(child->clone().get());
	}
}

HtmlNodeWithChildren::~HtmlNodeWithChildren()
{
	HtmlNode* child;
	while ((child = m_leftSentinel.getNextSibling())) {
		child->detachFromParent();
	}
}

bool
HtmlNodeWithChildren::hasChildren() const
{
	return m_leftSentinel.getNextSibling();
}

HtmlNode*
HtmlNodeWithChildren::getFirstChild()
{
	return m_leftSentinel.getNextSibling();
}

HtmlNode const*
HtmlNodeWithChildren::getFirstChild() const
{
	return m_leftSentinel.getNextSibling();
}

HtmlNode*
HtmlNodeWithChildren::getLastChild()
{
	return m_rightSentinel.getPrevSibling();
}

HtmlNode const*
HtmlNodeWithChildren::getLastChild() const
{
	return m_rightSentinel.getPrevSibling();
}

void
HtmlNodeWithChildren::appendChild(HtmlNode* node)
{
	node->insertBefore(&m_rightSentinel);
}

void
HtmlNodeWithChildren::prependChild(HtmlNode* node)
{
	node->insertAfter(&m_leftSentinel);
}

void
HtmlNodeWithChildren::removeAllChildren()
{
	HtmlNode* child;
	while ((child = m_leftSentinel.getNextSibling())) {
		child->detachFromParent();
	}
}


/*================= HtmlNodeWithChildren::Sentinel =================== */

HtmlNodeWithChildren::Sentinel::Sentinel(HtmlNode* parent)
:	HtmlNode(parent)
{
}

HtmlNodeWithChildren::Sentinel::~Sentinel()
{
}

HtmlNodePtr
HtmlNodeWithChildren::Sentinel::clone() const
{
	return HtmlNodePtr();
}

HtmlNode::NodeType
HtmlNodeWithChildren::Sentinel::getNodeType() const
{
	return FRAGMENT_NODE;
}

==> bfilter_1.0.9.orig.tar.gz: bfilter-1.0.9/main/HtmlNodeWithChildren.cpp <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "pch.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "HtmlNodeWithChildren.h"

HtmlNodeWithChildren::HtmlNodeWithChildren()
{
}

HtmlNodeWithChildren::HtmlNodeWithChildren(HtmlNodeWithChildren const& other)
{
	HtmlNode const* child = other.getFirstChild();
	for (; child; child = child->getNextSibling()) {
		appendChild(child->clone().get());
	}
}

HtmlNodeWithChildren::~HtmlNodeWithChildren()
{
	HtmlNode* child;
	while ((child = m_sentinel.getNextSibling())) {
		child->detachFromParent();
	}
}

bool
HtmlNodeWithChildren::hasChildren() const
{
	return m_sentinel.getNextSibling();
}

HtmlNode*
HtmlNodeWithChildren::getFirstChild()
{
	return m_sentinel.getNextSibling();
}

HtmlNode const*
HtmlNodeWithChildren::getFirstChild() const
{
	return m_sentinel.getNextSibling();
}

HtmlNode*
HtmlNodeWithChildren::getLastChild()
{
	return m_sentinel.getPrevSibling();
}

HtmlNode const*
HtmlNodeWithChildren::getLastChild() const
{
	return m_sentinel.getPrevSibling();
}

void
HtmlNodeWithChildren::appendChild(HtmlNode* node)
{
	insertChildBefore(node, &m_sentinel);
}

void
HtmlNodeWithChildren::prependChild(HtmlNode* node)
{
	insertChildAfter(node, &m_sentinel);
}

void
HtmlNodeWithChildren::removeAllChildren()
{
	HtmlNode* child;
	while ((child = m_sentinel.getNextSibling())) {
		child->detachFromParent();
	}
}


/*================= HtmlNodeWithChildren::Sentinel =================== */

HtmlNodeWithChildren::Sentinel::~Sentinel()
{
}

HtmlNodePtr
HtmlNodeWithChildren::Sentinel::clone() const
{
	return HtmlNodePtr();
}

HtmlNode::NodeType
HtmlNodeWithChildren::Sentinel::getNodeType() const
{
	return FRAGMENT_NODE;
}
